@@ -1,6 +1,5 @@
 import os
-
-import redis.asyncio as redis
+import redis
 
 host = os.getenv('REDIS_HOST', 'redis')
 redis_client = redis.Redis(host=host)
